weblogolib.LogoFormat

Package weblogolib :: Class LogoFormat |

# Class LogoFormat

source code

     object --+
              |
    LogoOptions --+
                  |
                 LogoFormat

    Specifies the format of the logo. Requires LogoData and LogoOptions
    objects.

    >>> data = LogoData.from_seqs(seqs )
    >>> options = LogoOptions()
    >>> options.title = "A Logo Title"
    >>> format = LogoFormat(data, options)

    Raises an ArgumentError if arguments are invalid.

Instance Methods
__init__(self, data, options=None) Create a new LogoFormat instance. | source code
Inherited from `LogoOptions`: `__repr__` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__str__`

Properties
Inherited from `object`: `__class__`

Method Details

### __init__(self, data, options=None) (Constructor) | source code
    Create a new LogoFormat instance.
Overrides: object.__init__